# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class ReactGridLayoutConfig(UniversalBaseModel):
    cols: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of columns in the grid
    """

    row_height: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="rowHeight")] = pydantic.Field(
        default=None
    )
    """
    Height of a single row in pixels
    """

    margin: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    Margin between items [x, y]
    """

    container_padding: typing_extensions.Annotated[
        typing.Optional[typing.List[int]], FieldMetadata(alias="containerPadding")
    ] = pydantic.Field(default=None)
    """
    Padding around the container [x, y]
    """

    is_draggable: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="isDraggable")] = (
        pydantic.Field(default=None)
    )
    """
    Whether items can be dragged
    """

    is_resizable: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="isResizable")] = (
        pydantic.Field(default=None)
    )
    """
    Whether items can be resized
    """

    auto_size: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="autoSize")] = pydantic.Field(
        default=None
    )
    """
    Whether the container should auto-size to fit contents
    """

    use_css_transforms: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="useCssTransforms")] = (
        pydantic.Field(default=None)
    )
    """
    Whether to use CSS transforms for positioning
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class TimeSeriesConfig(UniversalBaseModel):
    """
    Configuration specific to a time series component.
    """

    title: str = pydantic.Field()
    """
    The user-defined title of the chart.
    """

    y_axis_label: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="yAxisLabel")] = pydantic.Field(
        default=None
    )
    """
    Label for the Y-axis.
    """

    unit: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unit for the Y-axis values, e.g., 'MW'.
    """

    datasets: typing.List[str] = pydantic.Field()
    """
    List of timeseries dataset IDs to display on this chart.
    """

    formula: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional formula to combine datasets, e.g., 'dataset_1 + dataset_2'
    """

    echarts_options: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="echartsOptions")
    ] = pydantic.Field(default=None)
    """
    Optional ECharts options for the chart.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .create_geospatial_static_api_v_1_dashboard_datasets_geospatial_static_post_request_geometry_type import (
    CreateGeospatialStaticApiV1DashboardDatasetsGeospatialStaticPostRequestGeometryType,
)
from .create_timeseries_live_api_v_1_dashboard_datasets_timeseries_live_post_request_data_format import (
    CreateTimeseriesLiveApiV1DashboardDatasetsTimeseriesLivePostRequestDataFormat,
)

__all__ = [
    "CreateGeospatialStaticApiV1DashboardDatasetsGeospatialStaticPostRequestGeometryType",
    "CreateTimeseriesLiveApiV1DashboardDatasetsTimeseriesLivePostRequestDataFormat",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .map_layer_type import MapLayerType
from .ui_config import UiConfig


class MapLayer(UniversalBaseModel):
    """
    Standard map layer for geospatial data visualization.
    """

    id: typing.Optional[str] = None
    user_id: typing_extensions.Annotated[str, FieldMetadata(alias="userId")]
    name: str = pydantic.Field()
    """
    User-defined name for the layer, e.g., 'Danish Wind Turbines'.
    """

    deckgl_props: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="deckglProps")
    ] = pydantic.Field(default=None)
    """
    Base DeckGL layer configuration (styling, interactions, etc.).
    """

    ui_config: typing_extensions.Annotated[typing.Optional[UiConfig], FieldMetadata(alias="uiConfig")] = pydantic.Field(
        default=None
    )
    """
    Configuration for interactive UI controls that can modify layer properties.
    """

    created_at: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="createdAt")] = None
    updated_at: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="updatedAt")] = None
    type: MapLayerType = pydantic.Field()
    """
    DeckGL layer type
    """

    dataset_id: typing_extensions.Annotated[str, FieldMetadata(alias="datasetId")] = pydantic.Field()
    """
    Reference to dataset providing the data for this layer
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.map_layer import MapLayer
from ...types.weather_layer import WeatherLayer

ListLayersApiV1DashboardLayersGetResponseItem = typing.Union[WeatherLayer, MapLayer]



# This file was auto-generated by Fern from our API Definition.

import typing

UpdateLayerApiV1DashboardLayersLayerIdPutRequestMapLayerType = typing.Union[
    typing.Literal["ScatterPlotLayer", "GeoJsonLayer"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .dataformat import Dataformat


class LiveDataSource(UniversalBaseModel):
    url: str = pydantic.Field()
    """
    Base URL for the external API
    """

    params: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Query parameters with {start}/{end} placeholders
    """

    data_format: typing_extensions.Annotated[typing.Optional[Dataformat], FieldMetadata(alias="dataFormat")] = (
        pydantic.Field(default=None)
    )
    """
    Expected data format from API
    """

    aliases: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    Column name mapping (original -> target)
    """

    headers: typing.Optional[typing.Dict[str, typing.Optional[str]]] = pydantic.Field(default=None)
    """
    Optional HTTP headers
    """

    datetime_format: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="datetimeFormat")] = (
        pydantic.Field(default=None)
    )
    """
    strftime format for datetime parameters (e.g., '%Y-%m-%dT%H:%M' for DK API)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .ui_control_config_data_type import UiControlConfigDataType
from .ui_control_type import UiControlType


class UiControlConfig(UniversalBaseModel):
    """
    Configuration for a single UI control that can modify layer properties.
    """

    property: str = pydantic.Field()
    """
    Target DeckGL property name to modify, e.g., 'getFillColor', 'getRadius'
    """

    type: UiControlType = pydantic.Field()
    """
    Type of UI control to render
    """

    default: typing.Optional[typing.Any] = None
    options: typing.Optional[typing.List[typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Available options for dropdown/colorScheme/dataColumn types
    """

    range: typing.Optional[typing.List[float]] = pydantic.Field(default=None)
    """
    Min/max values for slider type [min, max]
    """

    label: typing.Optional[str] = pydantic.Field(default=None)
    """
    Display label for the control
    """

    data_type: typing_extensions.Annotated[
        typing.Optional[UiControlConfigDataType], FieldMetadata(alias="dataType")
    ] = pydantic.Field(default=None)
    """
    Expected data type for dataColumn controls
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
